# Pipeline Name

[![PyPI - Version](https://img.shields.io/pypi/v/pipeline-name.svg)](https://pypi.org/project/pipeline-name)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pipeline-name.svg)](https://pypi.org/project/pipeline-name)

-----

## Installation

```console
pip install pipeline-name
```

## About 

This is an example package showing how to use [snk](https://snk.wytamma.com/) to build self contained tools Snakemake pipeline tools. See [Pipeline Packages](https://snk.wytamma.com/pipeline_packages/) docs for more details.

## License

`pipeline-name` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
